# -*- coding: utf-8 -*-


from .compat import literal_eval


class DictSnippets(object):
    def __init__(self):
        self.separtor = ':'

    def eval_string(self, string):
        try:
            return literal_eval(string)
        except (SyntaxError, ValueError):
            return string

    def filter(self, obj, kvlist, exec_eval=True):
        _obj = {}
        for kv in kvlist:
            k, v = kv.split(self.separtor) if self.separtor in kv else [kv, '']
            _obj[k] = obj.get(k, self.eval_string(v) if exec_eval else v)
        return _obj

    def gets(self, obj, kvlist, exec_eval=True):
        """
        Get Multiple Values
        See: http://stackoverflow.com/questions/18453566/python-dictionary-get-list-of-values-for-list-of-keys
        :param obj:
        :param kvlist:
        :param exec_eval:
        :return:
        """
        _val = []
        for kv in kvlist:
            k, v = kv.split(self.separtor) if self.separtor in kv else [kv, '']
            _val.append(obj.get(k, self.eval_string(v) if exec_eval else v))
        return _val


_global_instance = DictSnippets()
filter = _global_instance.filter
gets = _global_instance.gets



# -*- coding: utf-8 -*-

"""
pythoncompat
"""

import sys


# -------
# Pythons
# -------

# Syntax sugar.
_ver = sys.version_info

#: Python 2.x?
is_py2 = (_ver[0] == 2)

#: Python 3.x?
is_py3 = (_ver[0] == 3)

try:
    from ast import literal_eval
except (ImportError, SyntaxError):
    # See: https://docs.python.org/2/library/ast.html
    # 32.2. ast — Abstract Syntax Trees
    # New in version 2.5: The low-level _ast module containing only the node classes.
    # New in version 2.6: The high-level ast module containing all helpers.
    literal_eval = eval

# ---------
# Specifics
# ---------

if is_py2:
    range = xrange

    builtin_str = str
    bytes = str
    str = unicode
    basestring = basestring
    numeric_types = (int, long, float)

    import __builtin__
    builtins = __builtin__

elif is_py3:
    range = range

    builtin_str = str
    str = str
    bytes = bytes
    basestring = (str, bytes)
    numeric_types = (int, float)

    import builtins
    builtins = builtins



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import re

from CodeConvert import CodeConvert as cc

from .compat import basestring


class StrSnippets(object):
    def strip_ascii_control_characters(self, s):
        # ASCII Control Characters
        return re.sub(r'[\x01-\x1F\x7F]', '', s)

    def strip(self, s, cc=False):
        if not isinstance(s, basestring):
            return s
        return self.strip_ascii_control_characters(s) if cc else s.strip()

    def trim(self, s, length=None, joint=''):
        if not isinstance(s, basestring):
            return s
        if length is None:
            return s
        return '{0}{1}'.format(s[:length], joint) if len(s) > length else s[:length]

    # https://github.com/fredshare/blog/issues/21
    # https://my.oschina.net/konglo/blog/738678
    def removeU2006(self, s, strip_whitespace=False):
        if not isinstance(s, basestring):
            return s
        if strip_whitespace:
            s = s.strip()
        return cc.Convert2Unicode(s).replace(u'\u2006', '').replace('\u2006', '')

    # https://blog.csdn.net/candyguy242/article/details/8476093
    # https://jianshu.com/p/72546884588a
    def removeU202C(self, s, strip_whitespace=False):
        if not isinstance(s, basestring):
            return s
        if strip_whitespace:
            s = s.strip()
        return cc.Convert2Unicode(s).replace(u'\u202c', '').replace('\u202c', '')

    def removeU202D(self, s, strip_whitespace=False):
        if not isinstance(s, basestring):
            return s
        if strip_whitespace:
            s = s.strip()
        return cc.Convert2Unicode(s).replace(u'\u202d', '').replace('\u202d', '')

    def removeAll(self, s, strip_whitespace=False):
        if not isinstance(s, basestring):
            return s
        if strip_whitespace:
            s = s.strip()
        return self.removeU202D(self.removeU202C(self.removeU2006(s)))

    def removeLineBreak(self, s):
        return s.replace('\r', '').replace('\n', '').replace('\r\n', '')


_global_instance = StrSnippets()
strip = _global_instance.strip
trim = _global_instance.trim
removeU2006 = _global_instance.removeU2006
removeU202C = _global_instance.removeU202C
removeU202D = _global_instance.removeU202D
removeAll = _global_instance.removeAll
removeLineBreak = _global_instance.removeLineBreak



# -*- coding: utf-8 -*-

from .compat import builtins


class ListSnippets(object):
    def all(self, list_, eles):
        return builtins.all([ele in list_ for ele in eles])

    def any(self, list_, eles):
        return builtins.any([ele in list_ for ele in eles])


_global_instance = ListSnippets()
all = _global_instance.all
any = _global_instance.any
